@@ -38,7 +38,7 @@ class RuleBasedDisambiguation:
             
         }
     
-    def label_disambiguation(self, sentence: str, labels: str) -> str:
+    def label_disambiguation(self, sentence: str, labels: str) -> tp.Tuple[str, str]:
         """
             Analyses the labels for a sentence and decides on a single valid label for the ambiguous or missing labels.
         
@@ -48,16 +48,22 @@ class RuleBasedDisambiguation:
         :type sentence: `str`
         :param labels: List of POS Tag labels for that sentence.
         :type labels: `str`
-        :return:
+        :return: A tuple with the preprocessed sentence and the labels for the words on the sentence.
+        :rtype: `tp.Tuple[str, str]`
         """
-        corrected_labels = [label.split('|') if '|' in label else [label] for label in labels.split()]
-        for index, label in enumerate(corrected_labels):
+        labels = [label.split('|') if '|' in label else [label] for label in labels.split()]
+        corrected_labels = labels.copy()
+        
+        for index, label in enumerate(labels):
             if len(label) > 1:
                 corrected_labels = self.__correct_label(sentence.split(), corrected_labels, index)
         
-        return ' '.join(['|'.join([label for label in word_labels]) if len(word_labels) > 1 else word_labels[0]
-                         for word_labels in corrected_labels]
-                        )
+        resulting_labels = ' '.join(
+            ['|'.join([label for label in word_labels]) if len(word_labels) > 1 else word_labels[0]
+             for word_labels in corrected_labels]
+            )
+        
+        return sentence, resulting_labels
     
     def __is_main_verb(self, word: str) -> bool:
         """
@@ -115,7 +121,7 @@ class RuleBasedDisambiguation:
     
     @staticmethod
     def __check_label_after(labels: tp.List[tp.List[str]], word_index: int,
-                            target_label: tp.List[str], steps_back: int = 1) -> bool:
+                            target_label: tp.List[str], steps_forward: int = 1) -> bool:
         """
             Checks if the word after the one on the `word_index` is of label `target_label`.
 
@@ -125,13 +131,13 @@ class RuleBasedDisambiguation:
         :type word_index: `int`
         :param target_label: Label being checked.
         :type target_label: `tp.List[str]`
-        :param steps_back: How many steps back is the word being checked. Defaults to one.
-        :type steps_back: `int`
+        :param steps_forward: How many steps back is the word being checked. Defaults to one.
+        :type steps_forward: `int`
         :return: Flags if the word is an auxiliary verb or not.
         :rtype: `bool`
         """
-        label_to_check = labels[word_index + steps_back]
-        if word_index < len(labels) - steps_back and any([label in target_label for label in label_to_check]):
+        if word_index < len(labels) - steps_forward and any([label in target_label
+                                                             for label in labels[word_index + steps_forward]]):
             return True
         else:
             return False
@@ -153,8 +159,7 @@ class RuleBasedDisambiguation:
         :return: Flags if the word is an auxiliary verb or not.
         :rtype: `bool`
         """
-        label_to_check = labels[word_index - steps_back]
-        if (word_index - steps_back >= 0) and any([label in target_label for label in label_to_check]):
+        if (word_index - steps_back >= 0) and any([label in target_label for label in labels[word_index - steps_back]]):
             return True
         else:
             return False
@@ -176,8 +181,7 @@ class RuleBasedDisambiguation:
         :return: Flags if the word is an auxiliary verb or not.
         :rtype: `bool`
         """
-        word_to_check = sentence[word_index - steps_back]
-        if (word_index - steps_back >= 0) and (word_to_check in target_words):
+        if (word_index - steps_back >= 0) and (sentence[word_index - steps_back] in target_words):
             return True
         else:
             return False
